==> libgtk-java-2.6.1.1.tar.gz: libgtk-java-2.6.1.1/src/java/org/gnu/gtk/VButtonBox.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import org.gnu.glib.Handle;
import org.gnu.glib.Type;

/**
 * GtkVButtonBox is a container desinged to display a collection of
 * buttons vertically.
 * <p>The methods for manipulating this widget are all stored in it's super
 * class, ButtonBox.
 * @see ButtonBox
 * @see HButtonBox
 */
public class VButtonBox extends ButtonBox 
{
	/**
	 * Creates a new VButtonBox Object, ready to have widgets added to it.
	 */
	public VButtonBox(){
		super(gtk_vbutton_box_new());
	}
	
	/**
	 * Construct a new VButtonBox from a handle to a native resource.
	 */
	public VButtonBox(Handle handle) {
	    super(handle);
	}
	
	/**
	 * Retrieve the runtime type used by the GLib library.
	 */
	public static Type getType() {
		return new Type(gtk_vbutton_box_get_type());
	}

    native static final protected int gtk_vbutton_box_get_type ();
    native static final protected Handle gtk_vbutton_box_new ();

    /*
    native static final private int gtk_vbutton_box_get_spacing_default();
    native static final private void gtk_vbutton_box_set_spacing_default(int spacing);
    native static final private int gtk_vbutton_box_get_layout_default();
    native static final private void gtk_vbutton_box_set_layout_default(int layout);
    */
}

==> libgtk-java-2.7.0.tar.gz: libgtk-java-2.7.0/src/java/org/gnu/gtk/VButtonBox.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import org.gnu.glib.Type;
import org.gnu.javagnome.Handle;

/**
 * GtkVButtonBox is a container desinged to display a collection of
 * buttons vertically.
 * <p>The methods for manipulating this widget are all stored in it's super
 * class, ButtonBox.
 * @see ButtonBox
 * @see HButtonBox
 */
public class VButtonBox extends ButtonBox 
{
	/**
	 * Creates a new VButtonBox Object, ready to have widgets added to it.
	 */
	public VButtonBox(){
		super(gtk_vbutton_box_new());
	}
	
	/**
	 * Construct a new VButtonBox from a handle to a native resource.
	 */
	public VButtonBox(Handle handle) {
	    super(handle);
	}
	
	/**
	 * Retrieve the runtime type used by the GLib library.
	 */
	public static Type getType() {
		return new Type(gtk_vbutton_box_get_type());
	}

    native static final protected int gtk_vbutton_box_get_type ();
    native static final protected Handle gtk_vbutton_box_new ();

    /*
    native static final private int gtk_vbutton_box_get_spacing_default();
    native static final private void gtk_vbutton_box_set_spacing_default(int spacing);
    native static final private int gtk_vbutton_box_get_layout_default();
    native static final private void gtk_vbutton_box_set_layout_default(int layout);
    */
}
